summaryrefslogtreecommitdiffstats
path: root/kpercentage/kpercentage/kanswer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpercentage/kpercentage/kanswer.h')
-rw-r--r--kpercentage/kpercentage/kanswer.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpercentage/kpercentage/kanswer.h b/kpercentage/kpercentage/kanswer.h
index 81392869..6837816b 100644
--- a/kpercentage/kpercentage/kanswer.h
+++ b/kpercentage/kpercentage/kanswer.h
@@ -50,12 +50,12 @@ class KAnswer : public KDialog
TQ_OBJECT
public:
/**
* The constructor doesn't need any parameters but the tqparent,
* because it will not be used in any other context.
*
- * @param tqparent Parent widget for modal functionality
+ * @param parent Parent widget for modal functionality
*/
- KAnswer( TQWidget *tqparent );
+ KAnswer( TQWidget *parent );
// public functions
/** setting/changing feedback text and pic */
@@ -50,12 +50,12 @@ class KAnswer : public KDialog
public:
/**
- * The constructor doesn't need any parameters but the tqparent,
+ * The constructor doesn't need any parameters but the parent,
* because it will not be used in any other context.
*